<?php
/**
 * Masterpiece Theme Customizer
 *
 * @package masterpiece
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
if ( ! function_exists( 'masterpiece_customize_register' ) ) {
	/**
	 * Register basic customizer support.
	 *
	 * @param object $wp_customize Customizer reference.
	 */
	function masterpiece_customize_register( $wp_customize ) {
		$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
		$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
		$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
	}
}
add_action( 'customize_register', 'masterpiece_customize_register' );

if ( ! function_exists( 'masterpiece_theme_customize_register' ) ) {
	/**
	 * Register individual settings through customizer's API.
	 *
	 * @param WP_Customize_Manager $wp_customize Customizer reference.
	 */
	function masterpiece_theme_customize_register( $wp_customize ) {

		// Theme layout settings.
		$wp_customize->add_section( 'masterpiece_theme_layout_options', array(
			'title'       => esc_html__( 'Theme Layout Settings', 'masterpiece' ),
			'capability'  => 'edit_theme_options',
			'description' => esc_html__( 'Container width and sidebar defaults', 'masterpiece' ),
			'priority'    => 160,
		) );

		/**
		 * Select sanitization function
		 *
		 * @param string               $input   Slug to sanitize.
		 * @param WP_Customize_Setting $setting Setting instance.
		 * @return string Sanitized slug if it is a valid choice; otherwise, the setting default.
		 */
        	function masterpiece_theme_slug_sanitize_select( $input, $setting ){

            	// Ensure input is a slug (lowercase alphanumeric characters, dashes and underscores are allowed only).
            	$input = sanitize_key( $input );

           		// Get the list of possible select options.
           		$choices = $setting->manager->get_control( $setting->id )->choices;

            	// If the input is a valid key, return it; otherwise, return the default.
            	return ( array_key_exists( $input, $choices ) ? $input : $setting->default );                

        	}

		$wp_customize->add_setting( 'masterpiece_container_type', array(
			'default'           => 'container',
			'type'              => 'theme_mod',
			'sanitize_callback' => 'masterpiece_theme_slug_sanitize_select',
			'capability'        => 'edit_theme_options',
		) );

		$wp_customize->add_control(
			new WP_Customize_Control(
				$wp_customize,
				'masterpiece_container_type', array(
					'label'       => esc_html__( 'Container Width', 'masterpiece' ),
					'description' => esc_html__( 'Choose between Bootstrap\'s container and container-fluid', 'masterpiece' ),
					'section'     => 'masterpiece_theme_layout_options',
					'settings'    => 'masterpiece_container_type',
					'type'        => 'select',
					'choices'     => array(
						'container-fluid' => esc_html__( 'Full width container', 'masterpiece' ),
						'container'       => esc_html__( 'Fixed width container', 'masterpiece' ),
					),
					'priority'    => '10',
				)
			) );

		$wp_customize->add_setting( 'masterpiece_sidebar_position', array(
			'default'           => 'right',
			'type'              => 'theme_mod',
			'sanitize_callback' => 'sanitize_text_field',
			'capability'        => 'edit_theme_options',
		) );

		$wp_customize->add_control(
			new WP_Customize_Control(
				$wp_customize,
				'masterpiece_sidebar_position', array(
					'label'       => esc_html__( 'Sidebar Positioning', 'masterpiece' ),
					'description' => esc_html__( 'Set sidebar\'s default position. Can either be: right, left, both or none. Note: this can be overridden on individual pages.',
					'masterpiece' ),
					'section'     => 'masterpiece_theme_layout_options',
					'settings'    => 'masterpiece_sidebar_position',
					'type'        => 'select',
					'sanitize_callback' => 'masterpiece_theme_slug_sanitize_select',
					'choices'     => array(
						'right' => esc_html__( 'Right sidebar', 'masterpiece' ),
						'left'  => esc_html__( 'Left sidebar', 'masterpiece' ),
						'both'  => esc_html__( 'Left & Right sidebars', 'masterpiece' ),
						'none'  => esc_html__( 'No sidebar', 'masterpiece' ),
					),
					'priority'    => '20',
				)
			) );

		/** ----- Color Options ----- **/
		$wp_customize->add_setting( 'primary_color', array(
			'default' => '#e84855',
			'type'              => 'theme_mod',
			'sanitize_callback' => 'sanitize_text_field',
			'capability'        => 'edit_theme_options',
		) );

		// add color picker control
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'primary_color', array(
			'label' => esc_html__('Primary Color', 'masterpiece'),
			'description' => esc_html__('Base color of the website. A bright vibrant color is suggest.', 'masterpiece'),
			'section' => 'colors',
			'settings' => 'primary_color',
		) ) );

		$wp_customize->add_setting( 'secondary_color', array(
			'default' => '#372248',
			'type'              => 'theme_mod',
			'sanitize_callback' => 'sanitize_text_field',
			'capability'        => 'edit_theme_options',
		) );

		// add color picker control
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'secondary_color', array(
			'label' => esc_html__('Secondary Color', 'masterpiece'),
			'description' => esc_html__('Secondary or auxilary color of the website. Helps to decorate the primary color. A dark and matching with primary color is suggested.', 'masterpiece'),
			'section' => 'colors',
			'settings' => 'secondary_color',
		) ) );

		$wp_customize->add_setting( 'tertiary_color', array(
			'default' => '#e8d7f1',
			'type'              => 'theme_mod',
			'sanitize_callback' => 'sanitize_text_field',
			'capability'        => 'edit_theme_options',
		) );

		// add color picker control
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'tertiary_color', array(
			'label' => esc_html__('Tertiary Color', 'masterpiece'),
			'description' => esc_html__('Mostly used for background purpose. A matching with Secondary color and lighter color is suggested.', 'masterpiece'),
			'section' => 'colors',
			'settings' => 'tertiary_color',
		) ) );

	}
} // endif function_exists( 'masterpiece_theme_customize_register' ).
add_action( 'customize_register', 'masterpiece_theme_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
if ( ! function_exists( 'masterpiece_customize_preview_js' ) ) {
	/**
	 * Setup JS integration for live previewing.
	 */
	function masterpiece_customize_preview_js() {
		wp_enqueue_script( 'masterpiece_customizer', get_template_directory_uri() . '/js/customizer.js',
			array( 'customize-preview' ), '20130508', true
		);
	}
}
add_action( 'customize_preview_init', 'masterpiece_customize_preview_js' );